Module: Declarative::Schema

Defined in:
lib/declarative/schema.rb

Overview

Include this to maintain inheritable, nested schemas with ::defaults and ::feature the way we have it in Representable, Reform, and Disposable.

The schema with its defnitions will be kept in ::definitions.

Requirements to includer: ::default_nested_class, override building with ::nested_builder.

Defined Under Namespace

Modules: DSL, Feature, Heritage